@@ -24,6 +24,7 @@ merge_list <- function(x, y) {
 #' @param metadata A named list containing metadata to pass to template.
 #' @param template Path to a pandoc template.
 #' @param output Path to save output.
+#' @param in_header Paths to files to include in the header.
 #' @return (Invisibly) The path of the generate file.
 #' @examples
 #' x <- rticles:::template_pandoc(
@@ -33,18 +34,20 @@ merge_list <- function(x, y) {
 #' )
 #' if (interactive()) file.show(x)
 #' @noRd
-template_pandoc <- function(metadata, template, output, verbose = FALSE) {
+template_pandoc <- function(metadata, template, output, in_header = NULL, verbose = FALSE) {
   tmp <- tempfile(fileext = ".md"); on.exit(unlink(tmp), add = TRUE)
   xfun::write_utf8(c("---", yaml::as.yaml(metadata), "---\n"), tmp)
 
   rmarkdown::pandoc_convert(
-    tmp, "markdown", output = output, verbose = verbose,
-    options = paste0("--template=", template),
+    tmp, output = output, verbose = verbose, wd = '.',
+    options = c(
+      "--template", rmarkdown::pandoc_path_arg(template),
+      rmarkdown::pandoc_include_args(in_header)
+    )
   )
   invisible(output)
 }
 
-
 # Helper function to create a custom format derived from pdf_document that
 # includes a custom LaTeX template
 pdf_document_format <- function(
@@ -55,6 +58,10 @@ pdf_document_format <- function(
   fmt
 }
 
-
-
-
+# recursion into a list to get an element using a vector of names
+get_list_element <- function(x, names) {
+  n <- length(names)
+  if (!is.list(x) || n == 0) return()
+  for (i in names[seq_len(n - 1)]) if (!is.list(x <- x[[i]])) return()
+  x[[names[n]]]
+}
